=================
Networking Huawei
=================

Neutron plugin to interact with Huawei SDN Controllers and OpenStack Neutron.

The Huawei Controller allows next-generation networks to follow SDN principles
throughout the engineering process through the provision of network services,
policy orchestration, and management functionality via the Open Services
Gateway initiation (OSGi) framework and Representational State Transfer (REST)
API interface capabilities, that allow service applications to employ network
capabilities through their defined interfaces. The result is that the
controller enables the orchestration of network-wide resources in support of
application services.

Support for below Huawei devices are implemented:

* Agile Controller(AC)

General
-------

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/networking-huawei
* Source: http://git.openstack.org/cgit/openstack/networking-huawei
* Bugs: http://bugs.launchpad.net/networking-huawei

Features
--------

* Support CRUD operations for ML2 resources like port, subnet and network.
* Support Security group functionality.
* Support router functionality.

